pub struct Db {
database: Vec<TigerHashMap<&'static str, DbEntry>>,
flags: Vec<(TigerHashSet<Token>, Option<fn(&Token, &Everything)>)>,
anonymous: Vec<DbEntry>,
items_lc: Vec<TigerHashMap<Lowercase<'static>, &'static str>>,
}Expand description
The main database of game items.
Fields
database: Vec<TigerHashMap<&'static str, DbEntry>>Items with full DbEntries, meaning a key and a block for each.
The Vec is indexed with an Item discriminant.
flags: Vec<(TigerHashSet<Token>, Option<fn(&Token, &Everything)>)>Items generated as side effects of the full items in database.
It allows only a limited form of validation.
The Vec is indexed with an Item discriminant.
anonymous: Vec<DbEntry>Items that have object identity but no usable name
items_lc: Vec<TigerHashMap<Lowercase<'static>, &'static str>>Lowercased registry of database items and flags, for case insensitive lookups
Implementations
Sourceimpl Db
impl Db
pub fn add( &mut self, item: Item, key: Token, block: Block, kind: Box<dyn DbKind>, )
pub fn add_exact_dup_ok( &mut self, item: Item, key: Token, block: Block, kind: Box<dyn DbKind>, )
fn add_inner( &mut self, item: Item, key: Token, block: Block, kind: Box<dyn DbKind>, exact_dup_ok: bool, )
Sourcefn add_inner2(
&mut self,
item: Item,
key: Token,
block: Block,
kind: Box<dyn DbKind>,
)
fn add_inner2( &mut self, item: Item, key: Token, block: Block, kind: Box<dyn DbKind>, )
Actually add the item to the database, replacing any of the same name that were there before.
pub fn add_flag(&mut self, item: Item, key: Token)
pub fn add_subitems(&mut self)
pub fn scan_variables(&self, registry: &mut Variables)
pub fn validate(&self, data: &Everything)
pub fn exists(&self, item: Item, key: &str) -> bool
pub fn exists_lc(&self, item: Item, key: &Lowercase<'_>) -> bool
pub fn get_item<T: DbKind + Any>( &self, item: Item, key: &str, ) -> Option<(&Token, &Block, &T)>
pub fn get_key_block(&self, item: Item, key: &str) -> Option<(&Token, &Block)>
pub fn has_property( &self, item: Item, key: &str, property: &str, data: &Everything, ) -> bool
pub fn lc_has_property( &self, item: Item, key: &Lowercase<'_>, property: &str, data: &Everything, ) -> bool
pub fn set_property(&mut self, item: Item, key: &str, property: &str)
pub fn validate_call( &self, item: Item, key: &Token, block: &Block, data: &Everything, sc: &mut ScopeContext, )
pub fn validate_use( &self, item: Item, key: &Token, block: &Block, data: &Everything, )
pub fn validate_property_use( &self, item: Item, key: &Token, data: &Everything, property: &Token, caller: &str, )
pub fn iter_key_block( &self, itype: Item, ) -> impl Iterator<Item = (&Token, &Block)>
pub fn iter_keys(&self, itype: Item) -> impl Iterator<Item = &Token>